Learn R Programming

dhga (version 0.1)

hub.pval.cutoff: Identification of hub genes in a Gene Co-expression Network based on gene connection significance values

Description

The function returns list of top ranked hub genes under a particular condition/trait

Usage

hub.pval.cutoff(x, beta, m, s, n)

Arguments

x
x is a data frame of gene expression values where rows represent genes and columns represent samples/time point under a particular condition/trait.
beta
beta is a soft threshold parameter determined from the scale free property of biological networks (Gene Co-expression Network).
m
m is a scalar representing sample size and is less than or equal to number of columns in x.
s
s is a scalar representing number of times each of the m samples will be resampled.
n
n is a scalar representing number of top ranked hub genes to be selected under that particular condition/trait

Value

Examples

Run this code
data(rice_salt)
x=as.data.frame(rice_salt)
beta=6
m=18
s=80
n=20
hub.pval.cutoff(x, beta, m, s, n)

Run the code above in your browser using DataLab