Learn R Programming

dhga (version 0.1)

hub.wgs: Identification of hub genes in a Gene Co-expression Network based on Weighted Gene Score

Description

The function returns the list of hub genes in a Gene Co-expression Network based on Weighted Gene Score without considering statistical significance values.

Usage

hub.wgs(x, beta, n)

Arguments

x
x is a data frame of gene expression values where rows represent genes and columns represent samples/time.
beta
beta is a soft threshold parameter determined from the scale free property of biological networks (Gene Co-expression Network).
n
n is a scalar representing number of genes to be declared as hub in the Gene Co-expression Network based on Weighted Gene Score.

Value

Examples

Run this code
data(rice_salt)

hub.wgs(rice_salt,beta=6, n=20)

Run the code above in your browser using DataLab