Learn R Programming

dhga (version 0.1)

rice_salt: The gene expression data of rice under salinity stress condition

Description

rice_salt data has the gene expression values of 200 genes over 20 samples. The row names of the data are the names of the probes.

Usage

data("rice_salt")

Arguments

Format

A data frame with 200 rows and 20 columns.

Wang J, Chen L, Wang Y, Zhang J, Liang Y, Xu D (2013) A Computational systems biology study for understanding salt tolerance mechanism in Rice. PLoS one 8(6): e64929. doi:10.1371/journal.pone.0064929.

Details

rice_salt data has the gene expression values of 200 genes identified by Wang et al. (2013). After loading the data, the dataset is available in R in the name of rice_salt object.

Examples

Run this code
data(rice_salt)

Run the code above in your browser using DataLab